<div class="header_part p-2 border d-flex justify-content-between">
    <div class="left_header">
        <div class="btn-toolbar" role="toolbar">
            <div class="btn-group me-2">
                <button type="button" class="btn openMenuBar">
                    <i class="hgi hgi-stroke hgi-menu-01"></i>
                </button>
                <button type="button" class="btn redirectToRoot">
                    <i class="hgi hgi-stroke hgi-home-01"></i>
                    <span>Home</span>
                </button>

                <div class="dropdown">
                    <button type="button" class="btn dropdown-toggle" data-bs-toggle="dropdown" aria-expanded="false">
                        <i class="hgi hgi-stroke hgi-cloud-upload"></i>
                        <span>Upload</span>
                    </button>
                    <ul class="dropdown-menu">
                        <li>
                            <button class="dropdown-item addNewUpload" type="button">Upload File</button>
                        </li>
                        <li>
                            <button class="dropdown-item addNewUrl" type="button">Upload URL</button>
                        </li>
                    </ul>
                </div>

                <button type="button" class="btn addNewFolder">
                    <i class="hgi hgi-stroke hgi-folder-add"></i>
                    <span>Add Folder </span>
                </button>

                <button type="button" class="btn refreshBtn">
                    <i class="hgi hgi-stroke hgi-folder-sync"></i>
                    <span>Refresh</span>
                </button>
            </div>
        </div>
    </div>

    <div class="right_header">
        <form method="get" class="filesSearchForm">
            <div class="input-group">
                <input type="search" name="s" class="form-control searchFilesInput" placeholder="Search"
                       aria-label="Search">
            </div>
        </form>
    </div>
</div>
